; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "23623x"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "23623y"
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "23623z"
command = ~D, DF, F, D, DF, F, z
time = 20

[Command]
name = "23623a"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
name = "23623b"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "23623c"
command = ~D, DF, F, D, DF, F, c
time = 20

[Command]
name = "214214a"
command = ~D, DB, B, D, DB, B, a
time = 20

[Command]
name = "214214b"
command = ~D, DB, B, D, DB, B, b
time = 20

[Command]
name = "214214c"
command = ~D, DB, B, D, DB, B, c
time = 20

[Command]
name = "214214x"
command = ~D, DB, B, D, DB, B, x
time = 20

[Command]
name = "214214y"
command = ~D, DB, B, D, DB, B, y
time = 20

[Command]
name = "214214z"
command = ~D, DB, B, D, DB, B, z
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "41236x"
command = ~B, D, F, x

[Command]
name = "41236y"
command = ~B, D, F, y

[Command]
name = "41236z"
command = ~B, D, F, z

[Command]
name = "4623x"
command = B, F, D, DF, x
;time = 10

[Command]
name = "4623y"
command = B, F, D, DF, y
;time = 10

[Command]
name = "4623z"
command = B, F, D, DF, z
;time = 10

[Command]
name = "623x"
command = ~F, D, DF, x

[Command]
name = "623y"
command = ~F, D, DF, y

[Command]
name = "623z"
command = ~F, D, DF, z

[Command]
name = "623a"
command = ~F, D, DF, a

[Command]
name = "623b"
command = ~F, D, DF, b

[Command]
name = "623c"
command = ~F, D, DF, c

[Command]
name = "214xy"
command = ~D, DB, B, x+y

[Command]
name = "214xz"
command = ~D, DB, B, x+z

[Command]
name = "214yz"
command = ~D, DB, B, y+z

[Command]
name = "214x"
command = ~D, DB, B, x

[Command]
name = "214y"
command = ~D, DB, B, y

[Command]
name = "214z"
command = ~D, DB, B, z

[Command]
name = "214a"
command = ~D, DB, B, a

[Command]
name = "214b"
command = ~D, DB, B, b

[Command]
name = "214c"
command = ~D, DB, B, c

[Command]
name = "236x"
command = ~D, DF, F, x

[Command]
name = "236y"
command = ~D, DF, F, y

[Command]
name = "236z"
command = ~D, DF, F, z

[Command]
name = "236a"
command = ~D, DF, F, a

[Command]
name = "236b"
command = ~D, DF, F, b

[Command]
name = "236c"
command = ~D, DF, F, c

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+a
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "back_x"
command = /$B,x
time = 2

[Command]
name = "back_y"
command = /$B,y
time = 2

[Command]
name = "back_z"
command = /$B,z
time = 2

[Command]
name = "back_c"
command = /$B,c
time = 2

[Command]
name = "back_b"
command = /$B,b
time = 2

[Command]
name = "back_a"
command = /$B,a
time = 2

[Command]
name = "fwd_a"
command = /$F,a
time = 2

[Command]
name = "fwd_c"
command = /$F,c
time = 2

[Command]
name = "fwd_b"
command = /$F,b
time = 2

[Command]
name = "back_ab"
command = /$B,a+b
time = 2

[Command]
name = "back_ac"
command = /$B,a+c
time = 2

[Command]
name = "back_bc"
command = /$B,b+c
time = 2

;-| {^ςȂ |---------------------------------------------------------

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 5

[Command]
name = "hold_c"
command = /c
time = 5

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_ab"
command = /a+b
time = 1

[Command]
name = "hold_bc"
command = /b+c
time = 1

[Command]
name = "hold_ac"
command = /a+c
time = 1

[Command]
name = "hold_xy"
command = /x+y
time = 1

[Command]
name = "hold_yz"
command = /y+z
time = 1

[Command]
name = "hold_xz"
command = /x+z
time = 1

[Command]
name = "hold_zc"
command = /c+z
time = 1

;-| Double Button |---------------------------------------------------------
[Command]
name = "xyz"
command = x+y+z
time = 1

[Command]
name = "xy"
command = x+y
time = 1

[Command]
name = "yz"
command = y+z
time = 1

[Command]
name = "xz"
command = x+z
time = 1

[Command]
name = "zc"
command = z+c
time = 1

[Command]
name = "xa"
command = x+a
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "ac"
command = a+c
time = 1

[Command]
name = "bc"
command = b+c
time = 1

;-| Single Button A |----------------------------------------------------
[Command]
name = "aaaaa"
command = a,a
time = 12

[Command]
name = "bbbbb"
command = b,b
time = 12

[Command]
name = "ccccc"
command = c,c
time = 12

[Command]
name = "xxxxx"
command = x,x
time = 12

[Command]
name = "yyyyy"
command = y,y
time = 12

[Command]
name = "zzzzz"
command = z,z
time = 12

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;Hit/Guard Spark p
;===========================================================================
;init Var(12)
[State -1,Var_12]
type                = Varset
trigger1            = RoundState  < 2       ; Not in Fight
v                   = 12
value               = 0                     ; <- LŗL̃GtFNggpꍇ́A
;                                           ;    Ɂu1vZbg܂B

;===========================================================================
;{[ p
;===========================================================================
;init Var(1)
[State -1,Var_1]
type                = Varset
trigger1            = RoundState  < 2       ; Not in Fight
v                   = 1 
value               = 128                   

;===========================================================================
;{p
;===========================================================================
;init Var(6)
[State -1,Var_6]
type                = Varset
trigger1            = RoundState  < 2       ; Not in Fight
v                   = 6
value               = 0

;init Var(9)
[State -1,Var_9]
type                = Varset
trigger1            = RoundState  < 2       ; Not in Fight
v                   = 9
value               = 0

;Player Side
[State -1,PlayerSide_2]
type                = Varset
trigger1            = Facing      = -1       ; 2P Side
trigger1            = RoundState  < 2       ; Not in Fight
v                   = 7
value               = 2

;Player Side
[State -1,PlayerSide_1]
type                = Varset
trigger1            = Facing       = 1       ; 1P Side
trigger1            = RoundState  < 2       ; Not in Fight
v                   = 7
value               = 1

;===========================================================================
;Bounus Messagep
;===========================================================================
;init Var(9)
[State -1,Var_9]
type               = VarAdd
trigger1           = Anim = [5000,5035]
trigger2           = MoveType = H  &&  StateNo != [120,159]
v                  = 9
value              = 1

;First Attack
[State -1, FA]
type               = Explod
triggerall         = Var(7) = 1    ; 1P Side
triggerall         = Var(9) = 0
triggerall         = NumExplod(13000) = 0
trigger1           = MoveHit
trigger2           = ProjHit1000 = 1
anim               = 13010
ID                 = 13000
pos                = -186, 50
postype            = front
facing             = 1
bindtime           = -1
removetime         = -2
sprpriority        = 1
ontop              = 1

;First Attack
[State -1, FA]
type               = Explod
triggerall         = Var(7) = 2    ; 2P Side
triggerall         = Var(9) = 0
triggerall         = NumExplod(13000) = 0
trigger1           = MoveHit
trigger2           = ProjHit1000 = 1
anim               = 13011
ID                 = 13000
pos                = 310, 50
postype            = front
facing             = -1
bindtime           = -1
removetime         = -2
sprpriority        = 1
ontop              = 1

;init Var(9)
[State -1,Var_9]
type               = VarAdd
trigger1           = MoveHit && (PrevStateNo != StateNo)
trigger2           = Anim = [5000,5022]
trigger3           = ProjHit1000 = 1
v                  = 9
value              = 1

;Reversal Attack
[State -1, RA]
type               = Explod
trigger1           = Var(7) = 1    ; 1P Side
trigger1           = NumExplod(13000) = 0
trigger1           = PrevStateNo = [5000,5999]
trigger1           = StateNo = [1000,3999]
anim               = 13000
ID                 = 13000
pos                = -156, 50
postype            = front
facing             = 1
bindtime           = -1
removetime         = -2
sprpriority        = 1
ontop              = 1

;Reversal Attack
[State -1, RA]
type               = Explod
trigger1           = Var(7) = 2    ; 2P Side
trigger1           = NumExplod(13000) = 0
trigger1           = PrevStateNo = [5000,5999]
trigger1           = StateNo = [1000,3999]
anim               = 13001
ID                 = 13000
pos                = 310, 50
postype            = front
facing             = -1
bindtime           = -1
removetime         = -2
sprpriority        = 1
ontop              = 1

;Recovery
[State -1, RCV]
type               = Explod
trigger1           = Var(7) = 1    ; 1P Side
trigger1           = NumExplod(13000) = 0
trigger1           = StateNo = [5200,5220]
;trigger1           = Time = 0
anim               = 13020
ID                 = 13000
pos                = -226, 50
postype            = front
facing             = 1
bindtime           = -1
removetime         = -2
sprpriority        = 1
ontop              = 1

;Recovery
[State -1, RCV]
type               = Explod
trigger1           = Var(7) = 2    ; 2P Side
trigger1           = NumExplod(13000) = 0
trigger1           = StateNo = [5200,5220]
;trigger1           = Time = 0
anim               = 13021
ID                 = 13000
pos                = 310, 50
postype            = front
facing             = -1
bindtime           = -1
removetime         = -2
sprpriority        = 1
ontop              = 1

;Super Combo Finish
[State -1, SCF]
type               = Explod
trigger1           = Var(7) = 1    ; 1P Side
trigger1           = NumExplod(13000) = 0
trigger1           = winKO = 1 && hitdefattr = SCA, HA && movehit = 1
anim               = 13030
ID                 = 13000
pos                = -196, 50
postype            = front
facing             = 1
bindtime           = -1
removetime         = -2
sprpriority        = 1
ontop              = 1

;Super Combo Finish
[State -1, SCF]
type               = Explod
trigger1           = Var(7) = 2    ; 2P Side
trigger1           = NumExplod(13000) = 0
trigger1           = winKO = 1 && hitdefattr = SCA, HA && movehit = 1
anim               = 13031
ID                 = 13000
pos                = 310, 50
postype            = front
facing             = -1
bindtime           = -1
removetime         = -2
sprpriority        = 1
ontop              = 1


;===========================================================================
; p
;===========================================================================
;[State -1, Fire]
;type              = Explod
;trigger1          = P2StateNo = 1315
;trigger1          = NumExplod(1315) = 0
;anim              = 1315
;ID                = 1315
;pos               = 0, 0
;postype           = p2
;facing            = -1
;bindtime          = -1
;removetime        = -1
;sprpriority       = 1
;ontop             = 0
;
;[State -1, Fire]
;type              = Explod
;trigger1          = P2StateNo = 1316
;trigger1          = NumExplod(1316) = 0
;anim              = 1316
;ID                = 1316
;pos               = 0, 0
;postype           = p2
;facing            = -1
;bindtime          = -1
;removetime        = -1
;sprpriority       = 1
;ontop             = 0
;
;[State -1, Fire]
;type              = Explod
;trigger1          = P2StateNo = 1317
;trigger1          = NumExplod(1317) = 0
;trigger2          = P2StateNo = 1316
;trigger2          = NumExplod(1316) = 0
;trigger2          = P2StateType = A
;anim              = 1317
;ID                = 1317
;pos               = 0, 0
;postype           = p2
;facing            = -1
;bindtime          = -1
;removetime        = -1
;sprpriority       = 1
;ontop             = 0
;
;[State -1, Fire off]
;type              = RemoveExplod
;trigger1          = P2StateNo != 1315
;trigger1          = NumExplod(1315) != 0
;ID                = 1315
;
;[State -1, Fire off]
;type              = RemoveExplod
;trigger1          = P2StateNo != 1316
;trigger1          = NumExplod(1316) != 0
;;trigger2          = P2StateNo != 1317
;;trigger2          = NumExplod(1316) != 0
;;trigger2          = P2StateType != S
;ID                = 1316
;
;[State -1, Fire off]
;type              = RemoveExplod
;trigger1          = P2StateNo != 1317
;trigger1          = NumExplod(1317) != 0
;ID                = 1317


;===========================================================================
;s͉p
[State -1, 1]
type       = VarAdd
trigger1   = Var(2) < 18
v          = 2
value      = 1

;---------------------------------------------------------------------------
;gij
[State -1, 1]
type       = Varset
trigger1   = Command = "236x"
v          = 0
value      = 1000

;---------------------------------------------------------------------------
;gij
[State -1, 1]
type       = Varset
trigger1   = Command = "236y"
v          = 0
value      = 1010

;---------------------------------------------------------------------------
;gij
[State -1, 1]
type       = Varset
trigger1   = Command = "236z"
v          = 0
value      = 1020

;---------------------------------------------------------------------------
;ij
[State -1, 1]
type       = Varset
trigger1   = Command = "623x"
v          = 0
value      = 1100

;---------------------------------------------------------------------------
;ij
[State -1, 1]
type       = Varset
trigger1   = Command = "623y"
v          = 0
value      = 1110

;---------------------------------------------------------------------------
;ij
[State -1, 1]
type       = Varset
trigger1   = Command = "623z"
v          = 0
value      = 1120

;---------------------------------------------------------------------------
;ij
[State -1, 1]
type       = Varset
trigger1   = Command = "623a"
v          = 0
value      = 1300

;---------------------------------------------------------------------------
;ij
[State -1, 1]
type       = Varset
trigger1   = Command = "623b"
v          = 0
value      = 1310

;---------------------------------------------------------------------------
;ij
[State -1, 1]
type       = Varset
trigger1   = Command = "623c"
v          = 0
value      = 1320

;---------------------------------------------------------------------------
;rij
[State -1, 1]
type       = Varset
trigger1   = Command = "214a"
v          = 0
value      = 1200

;---------------------------------------------------------------------------
;rij
[State -1, 1]
type       = Varset
trigger1   = Command = "214b"
v          = 0
value      = 1210

;---------------------------------------------------------------------------
;rij
[State -1, 1]
type       = Varset
trigger1   = Command = "214c"
v          = 0
value      = 1220

;---------------------------------------------------------------------------
;jiLv1j
[State -1, 1]
type       = Varset
trigger1   = Command = "23623x"
trigger1   = Power >= 1000
v          = 0
value      = 3000

;---------------------------------------------------------------------------
;jiLv2j
[State -1, 1]
type       = Varset
trigger1   = Command = "23623y"
trigger1   = Power >= 2000
v          = 0
value      = 3010

;---------------------------------------------------------------------------
;jiLv3j
[State -1, 1]
type       = Varset
trigger1   = Command = "23623z"
trigger1   = Power >= 3000
v          = 0
value      = 3020

;---------------------------------------------------------------------------
;_iLv1j
[State -1, 1]
type       = Varset
trigger1   = Command = "23623a"
trigger1   = Power >= 1000
v          = 0
value      = 3100

;---------------------------------------------------------------------------
;_iLv2j
[State -1, 1]
type       = Varset
trigger1   = Command = "23623b"
trigger1   = Power >= 2000
v          = 0
value      = 3110

;---------------------------------------------------------------------------
;_iLv3j
[State -1, 1]
type       = Varset
trigger1   = Command = "23623c"
trigger1   = Power >= 3000
v          = 0
value      = 3120

;---------------------------------------------------------------------------
;vr
[State -1, 1]
type       = Varset
triggerall = Power >= 3000
trigger1   = Command = "214214a"
trigger2   = Command = "214214b"
trigger3   = Command = "214214c"
v          = 0
value      = 3200

;---------------------------------------------------------------------------
;^
[State -1, 1]
type       = Varset
triggerall = Power >= 3000
trigger1   = Command = "214214x"
trigger2   = Command = "214214y"
trigger3   = Command = "214214z"
v          = 0
value      = 3300

;===========================================================================
;KEZinZj
[State -1, 0]
type = ChangeState
value = Var(0)
triggerall = Var(0) > 999
trigger1   = statetype = S || statetype = C
trigger1   = ctrl
trigger2   = stateno = 210 ; ߗo
;trigger2   = AnimElem = 3
trigger2   = movecontact
trigger3   = stateno = 220 ; ߗo
;trigger3   = AnimElem = 2
trigger3   = movecontact
trigger4   = stateno = 240 ; ߗj
;trigger4   = AnimElem = 4
trigger4   = movecontact
trigger5   = stateno = 241 ; jiPiځj
trigger5   = AnimElem = 4
trigger5   = movecontact
trigger6   = stateno = 410 ; o
;trigger6   = AnimElem = 3
trigger6   = movecontact
trigger7   = stateno = 420 ; o
;trigger7   = AnimElem = 2
trigger7   = movecontact
trigger8   = stateno = 440 ; j
;trigger8   = AnimElem = 3
trigger8   = movecontact
trigger9   = stateno = 450 ; j
;trigger9   = AnimElem = 2
trigger9   = movecontact
trigger10  = stateno = 300 ; ȂƊ
trigger10  = AnimElem = 5
trigger10  = movecontact
trigger11  = stateno = 310 ; 뗎ƂR
trigger11  = AnimElem = 7
trigger11  = movecontact
trigger12  = stateno = 320 ; O񂵏R
trigger12  = AnimElem = 6
trigger12  = movecontact

;KEZi󒆋Zj
[State -1, 0]
type = ChangeState
value = Var(0) + 30 + Var(6)
triggerall = Var(0) > 999
triggerall = Var(0) = [1200,1230]
trigger1   = statetype = A
trigger1   = ctrl
trigger2   = stateno = 600 ; 
trigger2   = movecontact
trigger3   = stateno = 610 ; 
trigger3   = movecontact
trigger4   = stateno = 620 ; 
trigger4   = movecontact
trigger5   = stateno = 630 ; 
trigger5   = movecontact
trigger6   = stateno = 640 ; 
trigger6   = movecontact
trigger7   = stateno = 650 ; 
trigger7   = movecontact

;===========================================================================
;Reversal KEZinZj
[State -1, 0]
type = ChangeState
value = Var(0)
triggerall = Var(0) > 999
trigger1   = statetype = S || statetype = C
trigger1   = stateno = 5001               ; 炢
trigger1   = HitOver
trigger2   = statetype = S || statetype = C
trigger2   = stateno = 5011               ; 炢
trigger2   = HitOver
trigger3   = stateno = 5120               ; N
trigger3   = AnimTime = 0

;Reversal KEZi󒆋Zj
[State -1, 0]
type = ChangeState
value = Var(0) + 30 + Var(6)
triggerall = Var(0) > 999
triggerall = Var(0) = [1200,1230]
triggerall = statetype = A
trigger1   = stateno = 5001               ; 炢
trigger1   = HitOver
trigger2   = stateno = 5011               ; 炢
trigger2   = HitOver

;===========================================================================
;s͉
[State -1, 1]
type       = Varset
trigger1   = Var(2) = 18
v          = 0
value      = 0

;s͉p
[State -1, 1]
type       = Varset
trigger1   = Var(2) = 18
v          = 2
value      = 0

;===========================================================================

;===========================================================================
;---------------------------------------------------------------------------
;===========================================================================

;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;w
[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "y" || command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 15
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 15
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;---------------------------------------------------------------------------
;n
[State -1, Throw]
type = ChangeState
value = 810
triggerall = command = "c"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 15
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 15
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;---------------------------------------------------------------------------
;Gn
[State -1, Throw]
type = ChangeState
value = 820
triggerall = command = "b"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 15
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 15
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H


;===========================================================================
;---------------------------------------------------------------------------
;뗎ƂR
[State -1, 1]
type = ChangeState
value = 310
;triggerall = command = "fwd_b" || command = "back_b"
triggerall = command = "back_b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;O񂵏R
[State -1, 1]
type = ChangeState
value = 320
;triggerall = command = "fwd_c" || command = "back_c"
triggerall = command = "back_c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;p`i߁j
[State -1, SSPunchInside]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 28
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;p`ij
[State -1, SSPunchOutside]
type = ChangeState
value = 201
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 28
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;p`i߁j
[State -1, SMPunchInside]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 28
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;p`ij
[State -1, SMPunchOutside]
type = ChangeState
value = 211
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 28
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;p`i߁j
[State -1, SLPunchInside]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 28
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;p`ij
[State -1, SLPunchOutside]
type = ChangeState
value = 221
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 28
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;LbNi߁j
[State -1, SSKickInside]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 36
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;LbNij
[State -1, SSKickOutside]
type = ChangeState
value = 231
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 36
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;LbNi߁j
[State -1, SMKickInside]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 28
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;LbNij
[State -1, SMKickOutside]
type = ChangeState
value = 241
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 28
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;LbNi߁j
[State -1, SLKickInside]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = P2BodyDist X < 42
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;LbNij
[State -1, SLKickOutside]
type = ChangeState
value = 251
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = P2BodyDist X >= 42
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;p`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;p`
[State -1, Crouching Middle Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Kick
;LbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Middle Kick
;LbN
[State -1, Crouching Middle Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Kick
;LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Wvp`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Wvp`
[State -1, Jump Middle Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Wvp`
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;WvLbN
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
triggerall = Vel X = 0
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;WvLbN
[State -1, Jump Middle Kick]
type = ChangeState
value = 640
triggerall = command = "b"
triggerall = Vel X = 0
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;WvLbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command = "c"
triggerall = Vel X = 0
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;WvLbN
[State -1, Jump Light Kick]
type = ChangeState
value = 631
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;WvLbN
[State -1, Jump Middle Kick]
type = ChangeState
value = 641
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;WvLbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 651
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl

